Change History
==============

0.2.1 (14th September 2014)
 - Handle a banner of None.
 - Fixed small typo in MANIFEST.in for the changelog.
 - Feels "snappier"

0.2.0 (25th June 2014)
 - Handle multiline statements much better.
 - setup.py pointed to wrong domain for project URL
 - Removed pointless insertion of '_' into the namespace.
 - Added lots of tests.
 - Feels "snappier"

0.1.1 (19th June 2014)
 - Use setuptools as a fallback when installing.
 - Feels "snappier"

0.1 (19th June 2014)
 - Initial release
 - Feels "snappier"
